use crate::codec2::Complex;

// 1 second @ 48KHz
const AVERAGE_TIME: usize = 48_000;

pub struct RemoveDcBias<I: Iterator<Item = Complex>> {
    iter: I,
    sum: Complex,
    i: usize,
    avg: Complex,
}

impl<I: Iterator<Item = Complex>> RemoveDcBias<I> {
    pub fn new(iter: I) -> Self {
        Self {
            iter,
            sum: Complex::zero(),
            i: 0,
            avg: Complex::zero(),
        }
    }
}

impl<I: Iterator<Item = Complex>> Iterator for RemoveDcBias<I> {
    type Item = Complex;

    fn next(&mut self) -> Option<Self::Item> {
        let val = self.iter.next()?;

        self.sum += val;
        self.i += 1;
        if self.i >= AVERAGE_TIME {
            self.avg = self.sum / (self.i as f32);
            self.i = 0;
            self.sum = Complex::zero();
        }

        Some(val - self.avg)
    }
}
